import { useState } from 'react';
import { Platform } from 'react-native';
import { checkMultiple, requestMultiple, RESULTS, openSettings, } from 'react-native-permissions';
import { useShow, useHide } from 'react-native-lifecycle';
/**
 * 权限
 * @param {Permission[]} permissions 权限列表
 * @param {RESULTS} permissionStatus default RESULTS.GRANTED
 * @public
 */
export default (permissions, permissionStatus = RESULTS.GRANTED) => {
    const [state, setState] = useState(null);
    permissions = permissions.filter(item => item && item.startsWith(Platform.OS));
    useShow(() => {
        checkMultiple(permissions).then(statuses => {
            setState(permissions.every(permission => statuses[permission] === permissionStatus));
        });
    });
    useHide(() => {
        setState(null);
    });
    const request = () => {
        return new Promise((resolve, reject) => {
            requestMultiple(permissions).then(statuses => {
                if (permissions.every(permission => statuses[permission] === RESULTS.GRANTED)) {
                    resolve();
                }
                else {
                    reject({
                        openSettings,
                    });
                }
            });
        });
    };
    return {
        state,
        request,
    };
};
